Move SkOSPath out of include/core.

It is moved to src/utils. It is almost a tool, but has two uses in
src/ports.

The existing SkOSFile.cpp is left empty for the time being since it is
mentioned in Chromium's BUILD.gn for Skia.

Change-Id: I3bb7f7c4214359eb6ab906bfe76737d20bf1d6c7
Reviewed-on: https://skia-review.googlesource.com/4536
Reviewed-by: Mike Klein <mtklein@chromium.org>
Commit-Queue: Ben Wagner <bungeman@google.com>
diff --git a/tests/OSPathTest.cpp b/tests/OSPathTest.cpp
index 3276145..22deff8 100644
--- a/tests/OSPathTest.cpp
+++ b/tests/OSPathTest.cpp
@@ -5,7 +5,7 @@
  * found in the LICENSE file.
  */
 
-#include "SkOSFile.h"
+#include "SkOSPath.h"
 #include "SkString.h"
 #include "Test.h"
 
@@ -15,24 +15,24 @@
  *  and tests using SkOSPath::Basename on the result.
  *  @param reporter Reporter for test conditions.
  *  @param dir String representing the path to a folder. May or may not
- *      end with SkPATH_SEPARATOR.
+ *      end with SkOSPath::SEPARATOR.
  *  @param filename String representing the basename of a file. Must NOT
- *      contain SkPATH_SEPARATOR.
+ *      contain SkOSPath::SEPARATOR.
  */
 static void test_dir_with_file(skiatest::Reporter* reporter, SkString dir,
                                SkString filename) {
-    // If filename contains SkPATH_SEPARATOR, the tests will fail.
-    SkASSERT(!filename.contains(SkPATH_SEPARATOR));
+    // If filename contains SkOSPath::SEPARATOR, the tests will fail.
+    SkASSERT(!filename.contains(SkOSPath::SEPARATOR));
 
     // Tests for SkOSPath::Join and SkOSPath::Basename
 
     // fullName should be "dir<SkPATH_SEPARATOR>file"
     SkString fullName = SkOSPath::Join(dir.c_str(), filename.c_str());
 
     // fullName should be the combined size of dir and file, plus one if
     // dir did not include the final path separator.
     size_t expectedSize = dir.size() + filename.size();
-    if (!dir.endsWith(SkPATH_SEPARATOR) && !dir.isEmpty()) {
+    if (!dir.endsWith(SkOSPath::SEPARATOR) && !dir.isEmpty()) {
         expectedSize++;
     }
     REPORTER_ASSERT(reporter, fullName.size() == expectedSize);
@@ -46,7 +46,7 @@
     // dirname should be the same as dir with any trailing seperators removed.
     // Except when the the string is just "/".
     SkString strippedDir = dir;
-    while (strippedDir.size() > 2 && strippedDir[strippedDir.size() - 1] == SkPATH_SEPARATOR) {
+    while (strippedDir.size() > 2 && strippedDir[strippedDir.size() - 1] == SkOSPath::SEPARATOR) {
         strippedDir.remove(strippedDir.size() - 1, 1);
     }
     if (!dirname.equals(strippedDir)) {
@@ -55,7 +55,7 @@
     REPORTER_ASSERT(reporter, dirname.equals(strippedDir));
 
     // basename will not contain a path separator
-    REPORTER_ASSERT(reporter, !basename.contains(SkPATH_SEPARATOR));
+    REPORTER_ASSERT(reporter, !basename.contains(SkOSPath::SEPARATOR));
 
     // Now take the basename of filename, which should be the same as filename.
     basename = SkOSPath::Basename(filename.c_str());
@@ -68,7 +68,7 @@
     test_dir_with_file(reporter, dir, filename);
 
     // Now make sure this works with a path separator at the end of dir.
-    dir.appendUnichar(SkPATH_SEPARATOR);
+    dir.appendUnichar(SkOSPath::SEPARATOR);
     test_dir_with_file(reporter, dir, filename);
 
     // Test using no filename.
@@ -82,7 +82,7 @@
     test_dir_with_file(reporter, dir, filename);
 
     // Basename of a directory with a path separator at the end is empty.
-    dir.appendUnichar(SkPATH_SEPARATOR);
+    dir.appendUnichar(SkOSPath::SEPARATOR);
     SkString baseOfDir = SkOSPath::Basename(dir.c_str());
     REPORTER_ASSERT(reporter, baseOfDir.size() == 0);
 
@@ -91,7 +91,7 @@
     REPORTER_ASSERT(reporter, empty.size() == 0);
 
     // File in root dir
-    dir.printf("%c", SkPATH_SEPARATOR);
+    dir.printf("%c", SkOSPath::SEPARATOR);
     filename.set("file");
     test_dir_with_file(reporter, dir, filename);
@@ -15,24 +15,24 @@
     // Tests for SkOSPath::Join and SkOSPath::Basename
 
-    // fullName should be "dir<SkPATH_SEPARATOR>file"
+    // fullName should be "dir<SkOSPath::SEPARATOR>file"
     SkString fullName = SkOSPath::Join(dir.c_str(), filename.c_str());
 